Class: Azure::StorageCache::Mgmt::V2020_10_01::Models::ApiOperation
- Inherits:
-
Object
- Object
- Azure::StorageCache::Mgmt::V2020_10_01::Models::ApiOperation
- Includes:
- MsRestAzure
- Defined in:
- lib/2020-10-01/generated/azure_mgmt_storagecache/models/api_operation.rb
Overview
REST API operation description: see github.com/Azure/azure-rest-api-specs/blob/master/documentation/openapi-authoring-automated-guidelines.md#r3023-operationsapiimplementation
Instance Attribute Summary collapse
-
#display ⇒ ApiOperationDisplay
The object that represents the operation.
-
#is_data_action ⇒ Boolean
to data plane.
-
#name ⇒ String
Operation name: provider/resource/operation.
-
#origin ⇒ String
Origin of the operation.
-
#service_specification ⇒ ApiOperationPropertiesServiceSpecification
the all the metrics provided for a resource type.
Class Method Summary collapse
-
.mapper ⇒ Object
Mapper for ApiOperation class as Ruby Hash.
Instance Attribute Details
#display ⇒ ApiOperationDisplay
Returns The object that represents the operation.
17 18 19 |
# File 'lib/2020-10-01/generated/azure_mgmt_storagecache/models/api_operation.rb', line 17 def display @display end |
#is_data_action ⇒ Boolean
to data plane.
24 25 26 |
# File 'lib/2020-10-01/generated/azure_mgmt_storagecache/models/api_operation.rb', line 24 def is_data_action @is_data_action end |
#name ⇒ String
Returns Operation name: provider/resource/operation.
27 28 29 |
# File 'lib/2020-10-01/generated/azure_mgmt_storagecache/models/api_operation.rb', line 27 def name @name end |
#origin ⇒ String
Returns Origin of the operation.
20 21 22 |
# File 'lib/2020-10-01/generated/azure_mgmt_storagecache/models/api_operation.rb', line 20 def origin @origin end |
#service_specification ⇒ ApiOperationPropertiesServiceSpecification
the all the metrics provided for a resource type.
31 32 33 |
# File 'lib/2020-10-01/generated/azure_mgmt_storagecache/models/api_operation.rb', line 31 def service_specification @service_specification end |
Class Method Details
.mapper ⇒ Object
Mapper for ApiOperation class as Ruby Hash. This will be used for serialization/deserialization.
38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/2020-10-01/generated/azure_mgmt_storagecache/models/api_operation.rb', line 38 def self.mapper() { client_side_validation: true, required: false, serialized_name: 'ApiOperation', type: { name: 'Composite', class_name: 'ApiOperation', model_properties: { display: { client_side_validation: true, required: false, serialized_name: 'display', type: { name: 'Composite', class_name: 'ApiOperationDisplay' } }, origin: { client_side_validation: true, required: false, serialized_name: 'origin', type: { name: 'String' } }, is_data_action: { client_side_validation: true, required: false, serialized_name: 'isDataAction', type: { name: 'Boolean' } }, name: { client_side_validation: true, required: false, serialized_name: 'name', type: { name: 'String' } }, service_specification: { client_side_validation: true, required: false, serialized_name: 'properties.serviceSpecification', type: { name: 'Composite', class_name: 'ApiOperationPropertiesServiceSpecification' } } } } } end |